@@ -7,22 +7,13 @@
 #ifndef LINUXCPU_H
 #define LINUXCPU_H
 
-struct sensors_chip_name;
-struct sensors_feature;
-
 #include "cpu.h"
 #include "usagecomputer.h"
 
 
-class TemperatureSensor : public KSysGuard::SensorProperty {
-public:
-    TemperatureSensor(const QString &id, KSysGuard::SensorObject *parent);
-    void setFeature(const sensors_chip_name * const chipName, const sensors_feature * const feature);
-    void update() override;
-private:
-    const sensors_chip_name * m_sensorChipName;
-    int m_temperatureSubfeature;
-};
+struct sensors_chip_name;
+struct sensors_feature;
+class SensorsFeatureSensor;
 
 class LinuxCpuObject : public CpuObject
 {
@@ -30,13 +21,12 @@ public:
     LinuxCpuObject(const QString &id, const QString &name, KSysGuard::SensorContainer *parent);
 
     void update(unsigned long long system, unsigned long long user, unsigned long long wait, unsigned long long idle);
-    TemperatureSensor* temperatureSensor();
     void initialize(double initialFrequency);
+    void makeTemperatureSensor(const sensors_chip_name * constchipName, const sensors_feature * const feature);
 private:
     void initialize() override {};
     void makeSensors() override;
     UsageComputer m_usageComputer;
-    TemperatureSensor *m_temperatureSensor;
 };
 
 class LinuxAllCpusObject : public AllCpusObject {
